"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = __importDefault(require("./commander"));
const subscriber_1 = __importDefault(require("./subscriber"));
class Webdis {
    constructor(url, options = {}) {
        this.dbIndex = options.db;
        this.prefixedUrl = this.dbIndex !== undefined ? `${url}/${this.dbIndex}` : url;
        this.commander = new commander_1.default(url, options);
        this.subscriptions = {};
    }
    command() {
        return this.commander;
    }
    // if found, then reuse and add a new listener
    // else create a new one
    subscribe(channel, cb) {
        const subscription = this.subscriptions[channel];
        if (subscription) {
            return subscription.registerCb(cb);
        }
        else {
            const subscriber = new subscriber_1.default(this.prefixedUrl, channel);
            this.subscriptions[channel] = subscriber;
            return subscriber.registerCb(cb);
        }
    }
    unsubscribe(channel, uuid) {
        const subscription = this.subscriptions[channel];
        if (subscription) {
            subscription.unregisterCb(uuid);
        }
        else {
            console.error(`No subscription found for channel: ${channel} and uuid: ${uuid}`);
        }
    }
    async quit() {
        for (const sub of Object.values(this.subscriptions)) {
            sub.destroy();
        }
    }
}
exports.default = Webdis;
