"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// https://github.com/nicolasff/webdis#pubsub-with-chunked-transfer-encoding
const uuid_1 = require("uuid");
// @ts-ignore
const xmlhttprequest_1 = require("xmlhttprequest");
const chalk_1 = __importDefault(require("chalk"));
class Subscriber {
    constructor(url, channel) {
        this.prevResponseLength = 0;
        this.listeners = {};
        this.channel = channel;
        this.url = url;
        this.xhr = new xmlhttprequest_1.XMLHttpRequest();
        this.xhr.addEventListener("readystatechange", () => this.onReadyStateChange());
        this.xhr.open("GET", `${this.url}/SUBSCRIBE/${this.channel}`);
        this.xhr.send(null);
    }
    onReadyStateChange() {
        var _a, _b;
        if (this.xhr.readyState === 3) {
            const response = this.xhr.responseText;
            const chunk = response.slice(this.prevResponseLength);
            this.prevResponseLength = response.length;
            // Received CHUNK:  {"SUBSCRIBE":["message","test","{\"some_field\": \"some_value\"}"]}
            try {
                const parsedChunk = JSON.parse(chunk);
                const isMessage = ((_a = parsedChunk === null || parsedChunk === void 0 ? void 0 : parsedChunk.SUBSCRIBE) === null || _a === void 0 ? void 0 : _a[0]) === "message";
                if (isMessage) {
                    // data will be available in index = 2
                    for (const cb of Object.values(this.listeners)) {
                        /**
                         * callback always gets parsed data.
                         * callback function should always check the type of data it is receiving then do operations on it.
                         */
                        cb((_b = parsedChunk === null || parsedChunk === void 0 ? void 0 : parsedChunk.SUBSCRIBE) === null || _b === void 0 ? void 0 : _b[2]);
                    }
                }
            }
            catch (e) {
                console.error(chalk_1.default.red(`Unable to process received message`, chunk), chalk_1.default.red(e));
            }
        }
    }
    registerCb(cb) {
        const uuid = (0, uuid_1.v4)();
        this.listeners[uuid] = cb;
        return uuid;
    }
    unregisterCb(uuid) {
        delete this.listeners[uuid];
    }
    destroy() {
        console.log(chalk_1.default.green(`Destroying subscription: `, this.channel));
        // empty the listeners
        this.listeners = {};
        // stop the xhr call
        this.xhr.abort();
    }
}
exports.default = Subscriber;
