import Commander from "./commander";
import Subscriber from "./subscriber";
class Webdis {
    constructor(url, options = {}) {
        this.dbIndex = options.db;
        this.prefixedUrl = this.dbIndex !== undefined ? `${url}/${this.dbIndex}` : url;
        this.commander = new Commander(url, options);
        this.subscriptions = {};
    }
    command() {
        return this.commander;
    }
    // if found, then reuse and add a new listener
    // else create a new one
    subscribe(channel, cb) {
        const subscription = this.subscriptions[channel];
        if (subscription) {
            return subscription.registerCb(cb);
        }
        else {
            const subscriber = new Subscriber(this.prefixedUrl, channel);
            this.subscriptions[channel] = subscriber;
            return subscriber.registerCb(cb);
        }
    }
    unsubscribe(channel, uuid) {
        const subscription = this.subscriptions[channel];
        if (subscription) {
            subscription.unregisterCb(uuid);
        }
        else {
            console.error(`No subscription found for channel: ${channel} and uuid: ${uuid}`);
        }
    }
    async quit() {
        for (const sub of Object.values(this.subscriptions)) {
            sub.destroy();
        }
    }
}
export default Webdis;
